@@ -97,6 +97,7 @@ Plot figure ...
 """
 
 import math
+import cmath
 import sys
 import warnings
 
@@ -118,13 +119,14 @@ les diagrammes de Bode")
 warnings.simplefilter('default', UserWarning)
 
 """ historique des versions
+0.4.0 : add poles
 0.3.9 : pep8 style
 0.3.8 : add warnings 2022-01
 0.3.7 : 2022-01
 0.0.1 : initial release 2021-11
 """
 
-__version__ = (0, 3, 9)
+__version__ = (0, 4, 0)
 __author__ = "Fabrice Sincère <fabrice.sincere@ac-grenoble.fr>"
 
 
@@ -157,6 +159,8 @@ w0 : pulsation propre (en rad/s)
         self.__coeff_amortissement = coeff_amortissement
         # pulsation propre
         self.__w0 = w0
+        # pôles
+        self.__poles = self.abaque_poles(self.__coeff_amortissement, self.__w0)
         # amplification statique
         self.__A = A
         # fonction de transfert complexe (module acelectricity)
@@ -189,6 +193,28 @@ Exemple :
         # getter
         return self.__coeff_amortissement
 
+    @property
+    def poles(self) -> tuple:
+        """ Retourne les 2 pôles de la fonction de transfert :
+
+                A                     A.w0²
+H(s) = ---------------------- = ----------------------
+         1 + 2ms/w0 +(s/w0)²    (s - pole1)(s - pole2)
+
+avec : s = jw (opérateur de Laplace)
+
+Exemple :
+>>> import order2
+>>> syst = order2.Ordre2(A=10, coeff_amortissement=0.6, w0=1000)
+>>> print(syst.poles)
+((-600+800j), (-600-800j))
+>>> syst = order2.Ordre2(A=10, coeff_amortissement=2, w0=1000)
+>>> print(syst.poles)
+(-267.94919..., -3732.05080...)
+"""
+        # getter
+        return self.__poles
+
     @property
     def amplification_statique(self) -> float:
         """ Retourne l'amplification statique (sans unité)
@@ -555,6 +581,100 @@ coeff_amortissement=0.16, w0=10000))
             warnings.warn('Valeur approchée avec une bonne approximation')
             return w0/(2*math.pi)/math.sqrt(2*(2*m*m-1))
 
+    @staticmethod
+    def abaque_poles(coeff_amortissement: float, w0: float) -> tuple:
+        """Retourne les 2 pôles de la fonction de transfert
+calculés à partir du coefficient d'amortissement et de la pulsation propre :
+
+                A                     A.w0²
+H(s) = ---------------------- = ----------------------
+         1 + 2ms/w0 +(s/w0)²    (s - pole1)(s - pole2)
+
+avec : s = jw (opérateur de Laplace)
+
+>>> import order2
+>>> print(order2.Ordre2.abaque_poles(coeff_amortissement=0, w0=1000))
+(1000j, -1000j)
+>>> print(order2.Ordre2.abaque_poles(0.6, 1000))
+((-600+800j), (-600-800j))
+>>> print(order2.Ordre2.abaque_poles(1, 1000))
+(-1000, -1000)
+>>> print(order2.Ordre2.abaque_poles(2, 1000))
+(-267.94919..., -3732.05080...)
+"""
+        m = coeff_amortissement
+        if m < 0:
+            raise ValueError("Le coefficient d'amortissement doit être positif")
+        if w0 <= 0:
+            raise ValueError("La pulsation propre doit être positive")
+        if m == 0.0:
+            return 1j*w0, -1j*w0
+        elif m == 1.0:
+            return -w0, -w0
+        elif 0.0 < m < 1.0:
+            # 2 pôles complexes conjugués
+            p1 = -m*w0 + 1j*w0*math.sqrt(1-m*m)
+            p2 = -m*w0 - 1j*w0*math.sqrt(1-m*m)
+            return p1, p2
+        else:
+            # m > 1
+            # 2 pôles réels négatifs
+            if m > 1e6:
+                # approximation (car la précision de la formule
+                # théorique se dégrade quand m augmente)
+                warnings.warn('Valeur approchée avec une bonne approximation')
+                p1 = -w0/(2*m)
+                p2 = -2*m*w0
+                return p1, p2
+            else:
+                p1 = -m*w0 + w0*math.sqrt(m*m-1)
+                p2 = -m*w0 - w0*math.sqrt(m*m-1)
+                return p1, p2
+
+    @staticmethod
+    def abaque_m_w0_depuis_poles(pole1: complex, pole2: complex) -> tuple:
+        """Retourne le tuple (coefficient d'amortissement, pulsation propre)
+calculé à partir des 2 pôles de la fonction de transfert :
+
+                A                     A.w0²
+H(s) = ---------------------- = ----------------------
+         1 + 2ms/w0 +(s/w0)²    (s - pole1)(s - pole2)
+
+avec : s = jw (opérateur de Laplace)
+
+>>> import order2
+>>> print(order2.Ordre2.abaque_m_w0_depuis_poles(-268, -3732))
+(1.99982..., 1000.087...)
+>>> print(order2.Ordre2.abaque_m_w0_depuis_poles(-1000, -1000))
+(1.0, 1000.0)
+>>> print(order2.Ordre2.abaque_m_w0_depuis_poles(-600+800j, -600-800j))
+(0.6, 1000.0)
+>>> print(order2.Ordre2.abaque_m_w0_depuis_poles(-1000j, 1000j))
+(0.0, 1000.0)
+"""
+        pole1 = complex(pole1)
+        pole2 = complex(pole2)
+        if pole1.imag == 0.0 and pole2.imag == 0.0:
+            # les deux pôles sont réels
+            # m >= 1
+            if pole1.real >= 0.0 or pole2.real >= 0.0:
+                raise ValueError("Partie réelle négative attendue")
+            tau1 = -1/pole1.real  # constante de temps (en seconde)
+            tau2 = -1/pole2.real
+            w0 = 1/math.sqrt(tau1*tau2)
+            m = (tau1+tau2)/(2*math.sqrt(tau1*tau2))
+            return m, w0
+        else:
+            # les deux pôles sont complexes
+            # 0 <= m < 1
+            if cmath.isclose(pole1, pole2.conjugate()) is False:
+                raise ValueError("Pôles complexes conjugués attendus")
+            if pole1.real > 0.0:
+                raise ValueError("Partie réelle négative attendue")
+            w0 = abs(pole1)
+            m = -pole1.real/w0
+            return m, w0
+
     @staticmethod
     def abaque_coeff_amortissement_harmonique(
             facteur_resonance_db: float) -> float:
@@ -1061,9 +1181,8 @@ Exemple :
 
 
 if __name__ == '__main__':
-    import order2
     # aide sur le module
-    help(order2)
+    help(__name__)
     # doctest
     import doctest
     doctest.testmod(verbose=True,
